@@ -9,8 +9,10 @@
 
 int lsetfilecon_raw(const char *path, security_context_t context)
 {
-	return lsetxattr(path, XATTR_NAME_SELINUX, context, strlen(context)+1, 0);
+	return lsetxattr(path, XATTR_NAME_SELINUX, context, strlen(context) + 1,
+			 0);
 }
+
 hidden_def(lsetfilecon_raw)
 
 int lsetfilecon(const char *path, security_context_t context)
@@ -18,13 +20,12 @@ int lsetfilecon(const char *path, security_context_t context)
 	int ret;
 	security_context_t rcontext = context;
 
-	if (context_translations && trans_to_raw_context(context, &rcontext))
+	if (selinux_trans_to_raw_context(context, &rcontext))
 		return -1;
 
- 	ret = lsetfilecon_raw(path, rcontext);
+	ret = lsetfilecon_raw(path, rcontext);
 
-	if (context_translations)
-		freecon(rcontext);
+	freecon(rcontext);
 
 	return ret;
 }
