@@ -1,4 +1,10 @@
-/* Copyright (c) 2006 Trusted Computer Solutions, Inc. */
+/* Author: Trusted Computer Solutions, Inc. 
+ * 
+ * Modified:
+ * Yuichi Nakamura <ynakam@hitachisoft.jp> 
+ - Stubs are used when DISABLE_SETRANS is defined, 
+   it is to reduce size for such as embedded devices.
+*/
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -7,7 +13,7 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <netdb.h>
-
+#include <fcntl.h>
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -16,6 +22,7 @@
 #include "selinux_internal.h"
 #include "setrans_internal.h"
 
+#ifndef DISABLE_SETRANS
 static int mls_enabled = -1;
 
 // Simple cache
@@ -23,6 +30,10 @@ static __thread security_context_t prev_t2r_trans = NULL;
 static __thread security_context_t prev_t2r_raw = NULL;
 static __thread security_context_t prev_r2t_trans = NULL;
 static __thread security_context_t prev_r2t_raw = NULL;
+static __thread char *prev_r2c_trans = NULL;
+static __thread security_context_t prev_r2c_raw = NULL;
+
+static pthread_once_t once = PTHREAD_ONCE_INIT;
 
 /*
  * setransd_open
@@ -35,11 +46,17 @@ static int setransd_open(void)
 {
 	struct sockaddr_un addr;
 	int fd;
-
-	fd = socket(PF_UNIX, SOCK_STREAM, 0);
-	if (fd < 0) {
-		return -1;
+#ifdef SOCK_CLOEXEC
+	fd = socket(PF_UNIX, SOCK_STREAM|SOCK_CLOEXEC, 0);
+	if (fd < 0 && errno == EINVAL)
+#endif
+	{
+		fd = socket(PF_UNIX, SOCK_STREAM, 0);
+		if (fd >= 0)
+			fcntl(fd, F_SETFD, FD_CLOEXEC);
 	}
+	if (fd < 0)
+		return -1;
 
 	memset(&addr, 0, sizeof(addr));
 	addr.sun_family = AF_UNIX;
@@ -199,18 +216,33 @@ static int trans_to_raw_context(char *trans, char **rawp)
 	return ret;
 }
 
-hidden void fini_context_translations(void)
+static int raw_context_to_color(char *raw, char **colors)
 {
-	free(prev_r2t_trans);
-	free(prev_r2t_raw);
-	free(prev_t2r_trans);
-	free(prev_t2r_raw);
+	int ret;
+	int32_t ret_val;
+	int fd;
+
+	fd = setransd_open();
+	if (fd < 0)
+		return fd;
+
+	ret = send_request(fd, RAW_CONTEXT_TO_COLOR, raw, NULL);
+	if (ret)
+		goto out;
+
+	ret = receive_response(fd, RAW_CONTEXT_TO_COLOR, colors, &ret_val);
+	if (ret)
+		goto out;
+
+	ret = ret_val;
+out:
+	close(fd);
+	return ret;
 }
 
-hidden int init_context_translations(void)
+static void init_context_translations(void)
 {
 	mls_enabled = is_selinux_mls_enabled();
-	return 0;
 }
 
 int selinux_trans_to_raw_context(security_context_t trans,
@@ -221,6 +253,8 @@ int selinux_trans_to_raw_context(security_context_t trans,
 		return 0;
 	}
 
+	__selinux_once(once, init_context_translations);
+
 	if (!mls_enabled) {
 		*rawp = strdup(trans);
 		goto out;
@@ -260,6 +294,8 @@ int selinux_raw_to_trans_context(security_context_t raw,
 		return 0;
 	}
 
+	__selinux_once(once, init_context_translations);
+
 	if (!mls_enabled) {
 		*transp = strdup(raw);
 		goto out;
@@ -290,3 +326,67 @@ int selinux_raw_to_trans_context(security_context_t raw,
 }
 
 hidden_def(selinux_raw_to_trans_context)
+
+int selinux_raw_context_to_color(security_context_t raw, char **transp)
+{
+	if (!raw) {
+		*transp = NULL;
+		return -1;
+	}
+
+	if (prev_r2c_raw && strcmp(prev_r2c_raw, raw) == 0) {
+		*transp = strdup(prev_r2c_trans);
+	} else {
+		free(prev_r2c_raw);
+		prev_r2c_raw = NULL;
+		free(prev_r2c_trans);
+		prev_r2c_trans = NULL;
+		if (raw_context_to_color(raw, transp))
+			return -1;
+		if (*transp) {
+			prev_r2c_raw = strdup(raw);
+			if (!prev_r2c_raw)
+				goto out;
+			prev_r2c_trans = strdup(*transp);
+			if (!prev_r2c_trans) {
+				free(prev_r2c_raw);
+				prev_r2c_raw = NULL;
+			}
+		}
+	}
+      out:
+	return *transp ? 0 : -1;
+}
+
+hidden_def(selinux_raw_context_to_color)
+#else /*DISABLE_SETRANS*/
+
+int selinux_trans_to_raw_context(security_context_t trans,
+				 security_context_t * rawp)
+{
+	if (!trans) {
+		*rawp = NULL;
+		return 0;
+	}
+
+	*rawp = strdup(trans);
+	
+	return *rawp ? 0 : -1;
+}
+
+hidden_def(selinux_trans_to_raw_context)
+
+int selinux_raw_to_trans_context(security_context_t raw,
+				 security_context_t * transp)
+{
+	if (!raw) {
+		*transp = NULL;
+		return 0;
+	}
+	*transp = strdup(raw);
+	
+	return *transp ? 0 : -1;
+}
+
+hidden_def(selinux_raw_to_trans_context)
+#endif /*DISABLE_SETRANS*/
